@@ -1,7 +1,5 @@
 from __future__ import with_statement
-from fabric.api import run, env
-from fabric.context_managers import cd
-from djangofab.util import local as local, safe_local
+from djangofab.api import *
 
 def update_remote():
     "Update remote checkout to the latest version"
